Struct Buffer
pub struct Buffer { /* private fields */ }wayland and Linux only.Expand description
A wrapper around a wl_buffer::WlBuffer which has been allocated via a SlotPool.
When this object is dropped, the buffer will be destroyed immediately if it is not active, or upon the server’s release if it is.
Implementations
impl Buffer
impl Buffer
pub fn attach_to(&self, surface: &WlSurface) -> Result<(), ActivateSlotError>
pub fn attach_to(&self, surface: &WlSurface) -> Result<(), ActivateSlotError>
Attach a buffer to a surface.
This marks the slot as active until the server releases the buffer, which will happen automatically assuming the surface is committed without attaching a different buffer.
Note: if you need to ensure that canvas() calls never return data that
could be attached to a surface in a multi-threaded client, make this call while you have
exclusive access to the corresponding SlotPool.
pub fn height(&self) -> i32
pub fn stride(&self) -> i32
pub fn canvas<'pool>(
&self,
pool: &'pool mut SlotPool,
) -> Option<&'pool mut [u8]>
pub fn canvas<'pool>( &self, pool: &'pool mut SlotPool, ) -> Option<&'pool mut [u8]>
Get the bytes corresponding to this buffer if drawing is permitted.
This may be smaller than the canvas associated with the slot.
pub fn activate(&self) -> Result<(), ActivateSlotError>
pub fn activate(&self) -> Result<(), ActivateSlotError>
Manually mark a buffer as active.
An active buffer prevents drawing on its slot until a Release event is received or until manually deactivated.
pub fn deactivate(&self) -> Result<(), ActivateSlotError>
pub fn deactivate(&self) -> Result<(), ActivateSlotError>
Manually mark a buffer as inactive.
This should be used when the buffer was manually marked as active or when a buffer was attached to a surface but not committed. Calling this function on a buffer that was committed to a surface risks making the surface contents undefined.