Struct Slot

pub struct Slot { /* private fields */ }
Available on crate feature wayland and Linux only.
A chunk of memory allocated from a SlotPool

Retaining this object is only required if you wish to resize or change the buffer’s format without changing the contents of the backing memory.

Implementations



impl Slot

pub fn has_active_buffers(&self) -> bool

Return true if there are buffers referencing this slot whose contents are being accessed by the server.

pub fn len(&self) -> usize

Returns the size, in bytes, of this slot.

pub fn canvas<'pool>( &self, pool: &'pool mut SlotPool, ) -> Option<&'pool mut [u8]>

Get the bytes corresponding to a given slot if drawing to the slot is permitted.

Returns None if there are active buffers in the slot or if the slot does not correspond to this pool.