Struct SlotPool

pub struct SlotPool { /* private fields */ }
Available on crate feature wayland and Linux only.

Implementations



impl SlotPool

pub fn new( len: usize, shm: &impl ProvidesBoundGlobal<WlShm, 1>, ) -> Result<SlotPool, CreatePoolError>

pub fn create_buffer( &mut self, width: i32, height: i32, stride: i32, format: Format, ) -> Result<(Buffer, &mut [u8]), CreateBufferError>

Create a new buffer in a new slot.

This returns the buffer and the canvas. The parameters are:

  • width: the width of this buffer (in pixels)
  • height: the height of this buffer (in pixels)
  • stride: distance (in bytes) between the beginning of a row and the next one
  • format: the encoding format of the pixels. Using a format that was not advertised to the wl_shm global by the server is a protocol error and will terminate your connection.

The Slot for this buffer will have exactly the size required for the data. It can be accessed via Buffer::slot to create additional buffers that point to the same data. This is required if you wish to change formats, buffer dimensions, or attach a canvas to multiple surfaces.

For more control over sizing, use Self::new_slot and Self::create_buffer_in.

pub fn canvas(&mut self, key: &impl CanvasKey) -> Option<&mut [u8]>

Get the bytes corresponding to a given slot or buffer if drawing to the slot is permitted.

Returns None if there are active buffers in the slot or if the slot does not correspond to this pool.

pub fn len(&self) -> usize

Returns the size, in bytes, of this pool.

pub fn resize(&mut self, size: usize) -> Result<(), Error>

Resizes the memory pool, notifying the server the pool has changed in size.

This is an optimization; the pool automatically resizes when you allocate new slots.

pub fn new_slot(&mut self, len: usize) -> Result<Slot, Error>

Create a new slot with the given size in bytes.

pub fn raw_data_mut(&mut self, slot: &Slot) -> &mut [u8]

Get the bytes corresponding to a given slot.

Note: prefer using Self::canvas, which will prevent drawing to a buffer that has not been released by the server.

Returns an empty buffer if the slot does not belong to this pool.

pub fn create_buffer_in( &mut self, slot: &Slot, width: i32, height: i32, stride: i32, format: Format, ) -> Result<Buffer, CreateBufferError>

Create a new buffer corresponding to a slot.

The parameters are:

  • width: the width of this buffer (in pixels)
  • height: the height of this buffer (in pixels)
  • stride: distance (in bytes) between the beginning of a row and the next one
  • format: the encoding format of the pixels. Using a format that was not advertised to the wl_shm global by the server is a protocol error and will terminate your connection